.. _index:

Mizani
======

Mizani is python library that provides the pieces necessary to create scales
for a graphics system. It is based on the R `Scales`_ package.

Contents
--------

.. toctree::
   :maxdepth: 1

   bounds
   breaks
   labels
   palettes
   transforms
   scale
   installation
   changelog


.. _Scales: https://github.com/hadley/scales
